EXPORTS
	?InitPsKeysNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 1 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::InitPsKeysNewL(void)
	?InitStartupReasonNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 2 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::InitStartupReasonNewL(void)
	?InitCriticalLevelsNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 3 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::InitCriticalLevelsNewL(void)
	0 @ 4 ABSENT; absent
	?WaitForPsKeyExactNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 5 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::WaitForPsKeyExactNewL(void)
	?WaitForPsKeyRangeNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 6 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::WaitForPsKeyRangeNewL(void)
	?SaShutdownNewL@SsmSystemCmdsFactory@@SAPAVMSsmCustomCommand@@XZ @ 7 NONAME ; class MSsmCustomCommand * SsmSystemCmdsFactory::SaShutdownNewL(void)

